@@ -1,9 +1,6 @@
 use strict;
 use warnings;
 package Plack::App::DAIA::Validator;
-{
-  $Plack::App::DAIA::Validator::VERSION = '0.45_1';
-}
 #ABSTRACT: DAIA validator and converter
 
 use CGI qw(:standard);
@@ -12,22 +9,6 @@ use Encode;
 use parent 'Plack::App::DAIA';
 use Plack::Util::Accessor qw(xsd xslt warnings);
 
-our ($FORMATS);
-BEGIN {
-    my %f = DAIA->formats;
-    $FORMATS = { map { $_ => $_ } keys %f };
-    $FORMATS->{html}     = 'DAIA/HTML';
-    $FORMATS->{json}     = 'DAIA/JSON';
-    $FORMATS->{xml}      = 'DAIA/XML';
-    $FORMATS->{rdfjson}  = 'DAIA/RDF (JSON)';
-    $FORMATS->{turtle}   = 'DAIA/RDF (Turtle)'   if $FORMATS->{turtle};
-    $FORMATS->{ntriples} = 'DAIA/RDF (NTriples)' if $FORMATS->{ntriples};
-    $FORMATS->{rdfxml}   = 'DAIA/RDF (RDF/XML)'  if $FORMATS->{rdfxml};
-    foreach (qw(dot svg)) {
-        $FORMATS->{$_} = "DAIA/RDF graph ($_)" if $FORMATS->{$_}; 
-    }
-}
-
 sub call {
     my ($self, $env) = @_;
     my $req = Plack::Request->new($env);
@@ -44,7 +25,7 @@ sub call {
     my $xsd = $self->xsd;
 
     my $informat  = lc($req->param('in'));
-    my $outformat = lc($req->param('out')) || lc($req->param('format')) || 'html';
+    my $outformat = lc($req->param('out')) || lc($req->param('format'));
 
     my $callback  = $req->param('callback') || ""; 
     $callback = "" unless $callback =~ /^[a-z][a-z0-9._\[\]]*$/i;
@@ -69,11 +50,11 @@ sub call {
         $daia = shift @daiaobjs;
     }
 
-    if ( $FORMATS->{$outformat} and $outformat ne 'html' ) {
+    if ( $outformat =~ /^(json|xml)$/ ) {
         $daia = DAIA::Response->new() unless $daia;
-        $daia->addMessage( $error, errno => 500, lang => 'en' ) if $error;
-        return $self->as_psgi( 200, $daia, $outformat, $req->param('callback') );
-    } elsif ( $outformat ne 'html' ) {
+        $daia->addMessage(error(500,'en' => $error)) if $error;
+        return $self->serialize( 200, $daia, $outformat, $req->param('callback') );
+    } elsif ( $outformat and $outformat ne 'html' ) {
         $error = "Unknown output format - using HTML instead";
     }
 
@@ -86,6 +67,7 @@ sub call {
 #        $msg .= div({class=>'msg'},"Use ". 
 #                    a({href=>url()."?url=$eurl"},'this URL') .
 #                    " to to directly pass the URL to this script.");
+
     }
 
     my $html = <<HTML;
@@ -113,6 +95,8 @@ sub call {
 <form method="post" accept-charset="utf-8" action="">
 HTML
 
+    # TODO: current value of informat/outformat
+
     $html .= $msg . $error .
      fieldset(label('Input: ',
             popup_menu('in',['','json','xml'],'',
@@ -124,24 +108,18 @@ HTML
       ).
       fieldset(
         label('Output: ',
-            popup_menu('out',
-                [ sort { $FORMATS->{$a} cmp $FORMATS->{$b} } keys %$FORMATS ], 
-                $outformat, $FORMATS )
+            popup_menu('out',['html','json','xml'],'html',
+                       {'html'=>'HTML','json'=>'DAIA/JSON','xml'=>'DAIA/XML'})
         ), '&#xA0;', 
         label('JSONP Callback: ', textfield(-name=>'callback',-value=>$callback))
       ).
       fieldset('<input type="submit" value="Convert" class="submit" />')
     ;
-    my $has_graphviz = grep /^(svg|dot)$/, keys %$FORMATS;
-    if ( $has_graphviz && $url && !$data) {
-       $html .= "<fieldset>See RDF graph <a href=\"?url=$eurl&format=svg\">as SVG</a></fieldset>";
-    }
     $html .= '</form>';
 
     if ($daia) {
       if ( $informat eq 'xml' or DAIA::guess($data) eq 'xml' ) {
-        # TODO: move this into module DAIA (validate option when parsing)
-        my ($schema, $parser); 
+        my ($schema, $parser); # TODO: move this into a DAIA library method
         eval { require XML::LibXML; };
         if ( $@ ) {
             $error = "XML::LibXML::Schema required to validate DAIA/XML";
@@ -165,31 +143,24 @@ HTML
          $html .= p("validation is rather lax so the input may be invalid - but it was parseable");
       }
       $html .= "<div id='result'>";
-      my ($pjson, $pxml, $pttl) = ("","","");
+      my ($pjson, $pxml) = ("","");
       if (!$data && $url) {
-        $pjson = $pxml = $pttl = "?callback=$callback&url=$eurl";
+        $pjson = $pxml = "?callback=$callback&url=$eurl";
         $pjson = " (<a href='$pjson&format=json'>get via proxy</a>)";
         $pxml  = " (<a href='$pxml&format=xml'>get via proxy</a>)";
-        #$pttl  = " (<a href='$pttl&format=turtle'>get via proxy</a>)";
       }
       $html .= "<h2 id='json'>Result in DAIA/JSON$pjson <a href='#top'>&#x2191;</a> <a href='#xml'>&#x2193;</a></h2>";
       $html .= pre(escapeHTML( encode('utf8',$daia->json( $callback ) )));
       $html .= "<h2 id='xml'>Result in DAIA/XML$pxml <a href='#json'>&#x2191;</a></h2>";
       $html .= pre(escapeHTML( encode('utf8',$daia->xml( xmlns => 1 ) )));
-      if ($FORMATS->{turtle}) {
-        $html .= "<h2 id='ttl'>Result in DAIA/RDF (Turtle) <a href='#json'>&#x2191;</a></h2>";
-        my $ttl = $daia->serialize('turtle');
-        $html .= pre(escapeHTML( encode('utf8', $ttl )));
-      }
       $html .= "</div>";
     }
 
-    $html .= "<div class='footer'>Based on ";
-    $html .= join ' and ', map {
-        "<a href='http://search.cpan.org/perldoc?$_'>$_</a> " . ($_->VERSION || '');
-    } qw(Plack::App::DAIA::Validator DAIA);
+    my $VERSION = $DAIA::VERSION;
     $html .= <<HTML;
-. Visit the <a href="http://github.com/gbv/daia/">DAIA project at github</a> for sources and details. 
+<div class='footer'>
+Based on <a href='http://search.cpan.org/perldoc?Plack::App::DAIA'>Plack::App::DAIA</a> $VERSION.
+Visit the <a href="http://github.com/gbv/daia/">DAIA project at github</a> for sources and details. 
 </div></body>
 HTML
 
@@ -198,18 +169,6 @@ HTML
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Plack::App::DAIA::Validator - DAIA validator and converter
-
-=head1 VERSION
-
-version 0.45_1
-
 =head1 SYNOPSIS
 
     use Plack::Builder;
@@ -223,29 +182,14 @@ version 0.45_1
             warnings => 1
         );
     };
-
+    
 =head1 DESCRIPTION
 
 This module provides a simple L<DAIA> validator and converter as PSGI web
 application.
 
-To support fetching from DAIA Servers via HTTPS you might need to install
-L<LWP::Protocol::https> version 6.02 or higher.
-
 =head1 CONFIGURATION
 
 All configuration parameters (C<xsd>, C<xslt>, and C<warnings>) are optional.
 
-=head1 AUTHOR
-
-Jakob Voss
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jakob Voss.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
-
